@@ -149,6 +149,9 @@ function M.expand(self, tbl)
 
    local init = false
 
+   local delayT = {}
+
+
    for k,v in pairsByKeys(tbl) do
       if (not init) then
          self:initialize()
@@ -178,8 +181,8 @@ function M.expand(self, tbl)
          self:alias(k,vstr)
       elseif (vType == "shell_function") then
          self:shellFunc(k,vstr)
-      elseif (vType == "complete") then
-         self:complete(k,vstr)
+      elseif (vType == "complete" or vType == "export_shell_function") then
+         delayT[k] = { vType = vType, vstr = vstr }
       elseif (not vstr) then
          self:unset(k, vType)
       elseif (k == "_ModuleTable_") then
@@ -190,6 +193,17 @@ function M.expand(self, tbl)
          end
       end
    end
+   if (next(delayT) ~= nil) then
+      for k, v in pairsByKeys(delayT) do
+         local vType = v.vType
+         if (vType == "complete") then
+            self:complete(k,v.vstr)
+         elseif (vType == "export_shell_function") then
+            self:export_shell_function(k,v.vstr)
+         end
+      end
+   end
+
    if (init) then
       self:finalize()
    end
@@ -235,6 +249,12 @@ function M.expandMT(self, vstr)
 end
 
 
+function M.export_shell_function(self, name, value)
+   -- This base function does nothing.
+   -- The shell functions must do something with it
+   -- if they want anything to happen.
+end
+
 function M.complete(self, name, value)
    -- This base function does nothing.
    -- The shell functions must do something with it
@@ -309,7 +329,7 @@ local function l_createShellTbl()
          ["lisp"]   = {name = "lisp",   object = Lisp   },
          ["csh"]    = {name = "csh",    object = Csh    },
          ["tcsh"]   = {name = "tcsh",   object = Csh    },
-         ["perl"]   = {name = "perl",   object = Perl   }, 
+         ["perl"]   = {name = "perl",   object = Perl   },
          ["python"] = {name = "python", object = Python },
          ["json"]   = {name = "json",   object = Json   },
          ["cmake"]  = {name = "cmake",  object = CMake  },
