@@ -104,7 +104,7 @@ local function l_findNamedCollections(a,pathA)
    local system_name  = cosmic:value("LMOD_SYSTEM_NAME")
    local t            = {}
    for i = 1,#pathA do
-      repeat 
+      repeat
          local path = pathA[i]
          if (not isDir(path)) then break end
          for file in lfs.dir(path) do
@@ -208,7 +208,7 @@ To get a list of every module in a category execute:
 
       local b = {}
       for cat, _ in pairsByKeys(categoryT) do
-         b[#b+1] = cat 
+         b[#b+1] = cat
       end
 
       b = hook.apply("category", "simple", b) or b
@@ -427,7 +427,7 @@ function List(...)
             s = s .. "\n" .. entry.origUserName
          end
          dbg.print{"fullName: ",entry.fullName, ", orig: ",entry.origUserName,", s: ",s,"\n"}
-         
+
          for j = 1, wanted.n do
             local p = wanted[j]
             if (s:find(p)) then
@@ -580,7 +580,8 @@ local function l_usrLoad(argA, check_must_load)
          LmodWarning{msg="w_Undef_MPATH"}
       end
 
-      local mcp_old = mcp
+      --local mcp_old = mcp
+      mcpStack:push(mcp)
       mcp           = MCP
       dbg.print{"Setting mcp to ", mcp:name(),"\n"}
       b             = mcp:load_usr(lA)
@@ -588,7 +589,8 @@ local function l_usrLoad(argA, check_must_load)
       if (haveWarnings() and check_must_load) then
          mcp.mustLoad()
       end
-      mcp           = mcp_old
+      --mcp           = mcp_old
+      mcp           = mcpStack:pop()
    end
 
    dbg.fini("l_usrLoad")
@@ -691,7 +693,7 @@ function Reset(msg)
          b[#b+1] = {k,v}
       end
    end
-   
+
    local function cmp(a,b)
       return a[2] < b[2]
    end
@@ -707,7 +709,7 @@ function Reset(msg)
       pathA = concatTbl(a," ")
    end
 
-   
+
    dbg.print{"default: \"",default,"\"\n"}
 
    default = default:trim()
@@ -747,10 +749,10 @@ local function l_collectionDir(mode)
       a[#a+1] = dotConfD
       a[#a+1] = dotLmodD
    end
-   return a 
+   return a
 end
-      
-            
+
+
 
 local function l_find_a_collection(collectionName)
    local pathA = l_collectionDir("read")
@@ -1204,6 +1206,7 @@ end
 --------------------------------------------------------------------------
 --  Reload all modules.
 function Update()
+   local mrc = MRC:singleton(); mrc:set_display_mode("all")
    local hub = Hub:singleton()
    local force_update = true
    hub:reloadAll(force_update)
@@ -1217,8 +1220,11 @@ function Use(...)
    dbg.start{"Use(", concatTbl({...},", "),")"}
    local mt       = FrameStk:singleton():mt()
    local a        = {}
-   local mcp_old  = mcp
-   local mcp      = MCP
+   --local mcp_old  = mcp
+   --local mcp      = MCP
+   mcpStack:push(mcp)
+   mcp            = MCP
+
    local op       = mcp.prepend_path
 
    local argA     = pack(...)
@@ -1266,7 +1272,8 @@ function Use(...)
       mt:reset_MPATH_change_flag()
       hub.reloadAll()
    end
-   mcp = mcp_old
+   --mcp = mcp_old
+   mcp = mcpStack:pop()
    dbg.fini("Use")
 end
 
@@ -1279,12 +1286,15 @@ function UnUse(...)
    local mt     = FrameStk:singleton():mt()
    local argA   = pack(...)
    local nodups = true
+
+   local mrc    = MRC:singleton();
+   mrc:set_display_mode("all")
+
    for i = 1, argA.n do
       local v = argA[i]
       MCP:remove_path{ModulePath,  v, delim=":", nodups = true, force = true}
    end
    if (mt:changeMPATH()) then
-      local mrc = MRC:singleton(); mrc:set_display_mode("all")
       mt:reset_MPATH_change_flag()
       hub.reloadAll()
    end
@@ -1296,7 +1306,7 @@ end
 function UnLoad(...)
    dbg.start{"UnLoad(",concatTbl({...},", "),")"}
    local force = false
-   unload_usr_internal(MName:buildA("mt", ...), force)
+   unload_usr_internal(MName:buildA("mt", pack(...)), force)
    mcp:mustLoad()
    dbg.fini("UnLoad")
 end
